from itertools import count

from fritzconnection import FritzConnection
from fritzconnection.core.exceptions import FritzServiceError
from fritzconnection.core.fritzconnection import os


def turn_off_wlan(fc):
    result = []
    action = "SetEnable"
    for n in count(1):
        service = f"WLANConfiguration{n}"
        try:
            fc.call_action(service, action, NewEnable=False)
        except FritzServiceError:
            break
        result.append(f"Turned off {service}")
    return result


def main(address, password):
    fc = FritzConnection(address=address, password=password)
    for result in turn_off_wlan(fc):
        print(f"{result}")


if __name__ == "__main__":
    password = os.environ["FRITZ_PASSWORD"]
    if password is None or password == "":
        print("Error: FRITZ_PASSWORD environment variable not set.")
        exit(1)

    main(address="192.168.178.1", password=password)
